Skip to contents

Draws a fourfold display of the confusion matrix with sensitivity and specificity annotated on the bottom margin.

Usage

# S3 method for class 'diag_test'
plot(x, col = c("#ffcccc", "#ccffcc"), main = "Confusion Matrix", ...)

Arguments

x

A diag_test object.

col

Character vector of length 2. Fill colours for the negative and positive quadrants respectively. Default: c("#ffcccc", "#ccffcc").

main

Character. Plot title. Default: "Confusion Matrix".

...

Additional arguments passed to graphics::fourfoldplot().

Value

Invisibly returns x.