Displays a formatted summary of the confusion matrix and all diagnostic performance metrics with confidence intervals.
Usage
# S3 method for class 'diag_test'
print(x, digits = 3L, ...)Displays a formatted summary of the confusion matrix and all diagnostic performance metrics with confidence intervals.
# S3 method for class 'diag_test'
print(x, digits = 3L, ...)