Learn R Programming

SimtablR (version 1.2.0)

plot.diag_test: Plot Diagnostic Test Results

Description

Draws a fourfold display of the confusion matrix with sensitivity and specificity annotated on the bottom margin.

Usage

# S3 method for diag_test
plot(x, col = c("#ffcccc", "#ccffcc"), main = "Confusion Matrix", ...)

Value

Invisibly returns x.

Arguments

x

A diag_test object.

col

Character vector of length 2. Fill colours for the negative and positive quadrants respectively. Default: c("#ffcccc", "#ccffcc").

main

Character. Plot title. Default: "Confusion Matrix".

...

Additional arguments passed to graphics::fourfoldplot().