Draws a fourfold display of the confusion matrix with sensitivity and specificity annotated on the bottom margin.
# S3 method for diag_test
plot(x, col = c("#ffcccc", "#ccffcc"), main = "Confusion Matrix", ...)Invisibly returns x.
A diag_test object.
Character vector of length 2. Fill colours for the negative and
positive quadrants respectively. Default: c("#ffcccc", "#ccffcc").
Character. Plot title. Default: "Confusion Matrix".
Additional arguments passed to graphics::fourfoldplot().